#!/bin/sh
# Version: 2.0
# This script is to be located in /etc/udev/scripts directory
# It is executed from /etc/udev/rules.d/automount.rules
# To view UTF8 encoded files correctly

MOUNT="/bin/mount"
PMOUNT="/usr/bin/pmount"
UMOUNT="/bin/umount"
CHMOD="/bin/chmod"

for line in `grep -h -v ^# /etc/udev/mount.blacklist /etc/udev/mount.blacklist.d/*`
do
	if [ ` expr match "$DEVNAME" "$line" ` -gt 0 ]; then
		#logger "udev/mount.sh" "[$DEVNAME] is blacklisted, ignoring"
		exit 0
	fi
done

if [ "$ID_PATH" == "platform-ci_hdrc.1-usb-0:1.1:1.0-scsi-0:0:0:0" ]; then
	name2=usb1
elif [ "$ID_PATH" == "platform-ci_hdrc.1-usb-0:1.2:1.0-scsi-0:0:0:0" ]; then
	name2=usb2
elif [ "$ID_PATH" == "platform-2194000.usdhc" ]; then
	name2=SD 
else
	logger "udev/mount.sh" "Skipping: $ID_PATH"
	exit 0
fi	




automount() {
	! test -d "/var/novexx/storage/external/$name2" && mkdir -p "/var/novexx/storage/external/$name2"

	# Silent util-linux's version of mounting auto
	if [ "x`readlink $MOUNT`" = "x/bin/mount.util-linux" ] ; then
		MOUNT="$MOUNT -o silent,sync"
	fi

	# If filesystem type is vfat, change the ownership group to 'disk', and
	# grant it with  w/r/x permissions.
	case $ID_FS_TYPE in
		vfat|fat)
			MOUNT="$MOUNT -o utf8,umask=000,iocharset=utf8,gid=`awk -F':' '/^disk/{print $3}' /etc/group`"
			;;
		# TODO
		*)
			;;
	esac



	if ! $MOUNT -t auto $DEVNAME "/var/novexx/storage/external/$name2"; then
		logger "mount.sh/automount" "$MOUNT -t auto $DEVNAME \"/var/novexx/storage/external/$name2\" failed!"
		rm -rfv "/var/novexx/storage/external/$name2"
	else
		logger "mount.sh/automount" "Auto-mount of $DEVNAME [/var/novexx/storage/external/$name2] successful"
		$CHMOD 775 "/var/novexx/storage/external/$name2"
	fi
}





rm_dir() {
	# We do not want to rm -r populated directories
	if test "`find "$1" | wc -l | tr -d " "`" -lt 2 -a -d "$1"; then
		! test -z "$1" && rm -r "$1"
	else
		logger "mount.sh/automount" "Not removing non-empty directory [$1]"
	fi
}





if expr $MAJOR "*" 256 + $MINOR != `stat -c %d /`; then
	grep -q "^$DEVNAME " /proc/mounts || automount
fi





if [ "$ACTION" = "remove" ] || [ "$ACTION" = "change" ] && [ -x "$UMOUNT" ] && [ -n "$DEVNAME" ]; then
	for mnt in `cat /proc/mounts | grep "$DEVNAME" | cut -f 2 -d " " `; do
		$UMOUNT $mnt || $UMOUNT -l $mnt
	done

	rm_dir "/var/novexx/storage/external/$name2"
fi
